# Development Practices

Generic development workflows and standards that could apply to any Python project.

---

## Development Workflow

| Guide | Topic |
|-------|-------|
| [Git Workflow](git.md) | Git branching, commits, merge strategy |
| [Commit Scopes](commit-scopes.md) | Comprehensive conventional commit scope reference |
| [Release](release.md) | Release and publishing workflow |
| [Justfile](justfile.md) | Just command reference |
| [Docs Writing](docs-writing.md) | MkDocs Material features and best practices |
| [Docs Design](docs-design.md) | Design system for documentation site |

---

## Code Standards

| Guide | Topic |
|-------|-------|
| [Python Style](python-style.md) | Python coding standards |
| [Testing](testing.md) | Testing strategy, markers, fixtures |
| [Logging](logging.md) | LogSpan patterns and best practices |
| [CLI Patterns](cli-patterns.md) | CLI development patterns |

---

## Quick Reference

| I want to... | See |
|--------------|-----|
| Make a commit | [Git Workflow](git.md) → Commit Format |
| Find commit scope | [Commit Scopes](commit-scopes.md) |
| Write tests | [Testing](testing.md) |
| Add logging | [Logging](logging.md) |
| Follow Python style | [Python Style](python-style.md) |
| Use just commands | [Justfile](justfile.md) |
| Release a version | [Release](release.md) |
| Build a CLI | [CLI Patterns](cli-patterns.md) |
| Write documentation | [Docs Writing](docs-writing.md) |
| Apply docs design system | [Docs Design](docs-design.md) |

---

**Note:** These practices use OneTool-specific tools (like LogSpan), but the patterns are generic enough to apply elsewhere.

---

**Related:**
- [OneTool Guides](../project/guides/index.md) - OneTool-specific guides
- [Architecture](../project/arch/index.md) - OneTool architecture
